@@ -191,32 +191,6 @@ gs_window_override_user_time (GSWindow *window)
         gdk_x11_window_set_user_time (gtk_widget_get_window (GTK_WIDGET (window)), ev_time);
 }
 
-static void
-force_no_pixmap_background (GtkWidget *widget)
-{
-        static gboolean first_time = TRUE;
-
-        if (first_time) {
-                gtk_rc_parse_string ("\n"
-                                     "   style \"gs-theme-engine-style\"\n"
-                                     "   {\n"
-                                     "      bg_pixmap[NORMAL] = \"<none>\"\n"
-                                     "      bg_pixmap[INSENSITIVE] = \"<none>\"\n"
-                                     "      bg_pixmap[ACTIVE] = \"<none>\"\n"
-                                     "      bg_pixmap[PRELIGHT] = \"<none>\"\n"
-                                     "      bg[NORMAL] = { 0.0, 0.0, 0.0 }\n"
-                                     "      bg[INSENSITIVE] = { 0.0, 0.0, 0.0 }\n"
-                                     "      bg[ACTIVE] = { 0.0, 0.0, 0.0 }\n"
-                                     "      bg[PRELIGHT] = { 0.0, 0.0, 0.0 }\n"
-                                     "   }\n"
-                                     "   widget \"gs-window-drawing-area*\" style : highest \"gs-theme-engine-style\"\n"
-                                     "\n");
-                first_time = FALSE;
-        }
-
-        gtk_widget_set_name (widget, "gs-window-drawing-area");
-}
-
 static void
 gs_window_reset_background_surface (GSWindow *window)
 {
@@ -2306,6 +2280,15 @@ create_panel (GSWindow *window)
         gtk_widget_show_all (window->priv->panel);
 }
 
+static void
+on_drawing_area_realized (GtkWidget *drawing_area)
+{
+        GdkRGBA black = { 0.0, 0.0, 0.0, 1.0 };
+
+        gdk_window_set_background_rgba (gtk_widget_get_window (drawing_area),
+                                        &black);
+}
+
 static void
 gs_window_init (GSWindow *window)
 {
@@ -2353,13 +2336,16 @@ gs_window_init (GSWindow *window)
         gtk_widget_show (window->priv->drawing_area);
         gtk_widget_set_app_paintable (window->priv->drawing_area, TRUE);
         gtk_box_pack_start (GTK_BOX (window->priv->vbox), window->priv->drawing_area, TRUE, TRUE, 0);
+        g_signal_connect (window->priv->drawing_area,
+                          "realize",
+                          G_CALLBACK (on_drawing_area_realized),
+                          NULL);
+
         create_info_bar (window);
 
         window->priv->clock_tracker = g_object_new (GNOME_TYPE_WALL_CLOCK, NULL);
         g_signal_connect (window->priv->clock_tracker, "notify::clock", G_CALLBACK (on_clock_changed), window);
         update_clock (window);
-
-        force_no_pixmap_background (window->priv->drawing_area);
 }
 
 static void
